/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│vi: set net ft=c ts=2 sts=2 sw=2 fenc=utf-8                                :vi│
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2022 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/calls/calls.h"
#include "libc/dce.h"
#include "libc/log/check.h"
#include "libc/runtime/runtime.h"
#include "libc/testlib/testlib.h"

void SetUp(void) {
  if (getenv("_SUBPROCESS")) {
    if (!__argv[0]) {
      exit(0);
    } else {
      exit(7);
    }
  } else if (getenv("_WEIRDENV")) {
    for (char **e = environ; *e; ++e) {
      if (!strcmp(*e, "WEIRD")) {
        exit(0);
      }
    }
    exit(7);
  }
}

TEST(execve, testWeirdAnsiC89emptyArgv) {
  char *prog;
  int pid, ws;
  if (IsWindows()) return;
  if (IsOpenbsd()) return;
  prog = GetProgramExecutableName();
  ASSERT_NE(-1, (pid = fork()));
  if (!pid) {
    execve(prog, (char *const[]){0}, (char *const[]){"_SUBPROCESS=1", 0});
    _Exit(127);
  }
  ASSERT_NE(-1, wait(&ws));
  EXPECT_TRUE(WIFEXITED(ws));
  EXPECT_EQ(0, WEXITSTATUS(ws));
}

TEST(execve, testWeirdEnvironmentVariable) {
  char *prog;
  int pid, ws;
  if (IsWindows()) return;
  if (IsOpenbsd()) return;
  prog = GetProgramExecutableName();
  ASSERT_NE(-1, (pid = fork()));
  if (!pid) {
    execve(prog, (char *const[]){prog, 0},
           (char *const[]){"_WEIRDENV=1", "WEIRD", 0});
    _Exit(127);
  }
  ASSERT_NE(-1, wait(&ws));
  EXPECT_TRUE(WIFEXITED(ws));
  EXPECT_EQ(0, WEXITSTATUS(ws));
}
