/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│vi: set net ft=c ts=2 sts=2 sw=2 fenc=utf-8                                :vi│
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2020 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/dce.h"
#include "libc/errno.h"
#include "libc/sysv/consts/o.h"
#include "libc/testlib/testlib.h"
#include "libc/x/x.h"

char testlib_enable_tmp_setup_teardown;

TEST(open, efault) {
  ASSERT_SYS(EFAULT, -1, open(0, O_RDONLY));
  if (IsWindows() && !IsAsan()) return;  // not possible
  ASSERT_SYS(EFAULT, -1, open((void *)77, O_RDONLY));
}

TEST(open, enoent) {
  ASSERT_SYS(ENOENT, -1, open("", O_RDONLY));
  ASSERT_SYS(ENOENT, -1, open("doesnotexist", O_RDONLY));
  ASSERT_SYS(ENOENT, -1, open("o/doesnotexist", O_RDONLY));
}

TEST(open, enotdir) {
  ASSERT_SYS(0, 0, touch("o", 0644));
  ASSERT_SYS(ENOTDIR, -1, open("o/doesnotexist", O_RDONLY));
}

TEST(open, eexist) {
  ASSERT_SYS(0, 0, touch("exists", 0644));
  ASSERT_SYS(EEXIST, -1, open("exists", O_WRONLY | O_CREAT | O_EXCL));
}

TEST(open, enametoolong) {
  size_t n = 260;
  char *s = gc(xcalloc(1, n + 1));
  memset(s, 'J', n);
  ASSERT_SYS(ENAMETOOLONG, -1, creat(s, 0644));
}

TEST(open, testOpenExistingForWriteOnly_seeksToStart) {
  char buf[8] = {0};
  ASSERT_SYS(0, 0, xbarf("hello.txt", "hello", -1));
  ASSERT_SYS(0, 3, open("hello.txt", O_WRONLY));
  EXPECT_SYS(0, 1, write(3, "H", 1));
  EXPECT_SYS(0, 0, close(3));
  ASSERT_SYS(0, 3, open("hello.txt", O_RDONLY));
  EXPECT_SYS(0, 5, read(3, buf, 7));
  EXPECT_STREQ("Hello", buf);
  EXPECT_SYS(0, 0, close(3));
}

TEST(open, testOpenExistingForReadWrite_seeksToStart) {
  char buf[8] = {0};
  ASSERT_SYS(0, 0, xbarf("hello.txt", "hello", -1));
  ASSERT_SYS(0, 3, open("hello.txt", O_RDWR));
  EXPECT_SYS(0, 1, write(3, "H", 1));
  EXPECT_SYS(0, 0, close(3));
  ASSERT_SYS(0, 3, open("hello.txt", O_RDONLY));
  EXPECT_SYS(0, 5, read(3, buf, 7));
  EXPECT_STREQ("Hello", buf);
  EXPECT_SYS(0, 0, close(3));
}

TEST(open, testOpenExistingForAppendWriteOnly_seeksToEnd) {
  char buf[8] = {0};
  ASSERT_SYS(0, 0, xbarf("hello.txt", "hell", -1));
  ASSERT_SYS(0, 3, open("hello.txt", O_WRONLY | O_APPEND));
  EXPECT_SYS(0, 1, write(3, "o", 1));
  EXPECT_SYS(0, 0, close(3));
  ASSERT_SYS(0, 3, open("hello.txt", O_RDONLY));
  EXPECT_SYS(0, 5, read(3, buf, 7));
  EXPECT_STREQ("hello", buf);
  EXPECT_SYS(0, 0, close(3));
}
